@@ -1,9 +1,10 @@
+# SPDX-FileCopyrightText: Tony DiCola for Adafruit Industries
+# SPDX-FileCopyrightText: 2019 Brent Rubell for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 # Example of using the Adafruit IO CircuitPython MQTT client
 # to subscribe to an Adafruit IO feed and publish random data
 # to be received by the feed.
-#
-# Example by Tony DiCola for Adafruit Industries
-# Modified by Brent Rubell for Adafruit Industries, 2019
 import time
 from random import randint
 
@@ -71,6 +72,7 @@ MQTT.set_socket(socket, eth)
 # Initialize a new MQTT Client object
 mqtt_client = MQTT.MQTT(
     broker="io.adafruit.com",
+    port=1883,
     username=secrets["aio_username"],
     password=secrets["aio_key"],
 )
